==> haskell-unordered-containers-0.2.7.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.7.1
id: unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
key: unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
license: BSD3
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
author: Johan Tibell
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.PopCount Data.HashMap.Unsafe Data.HashMap.UnsafeShift
abi: 672690eae431a5330d515b4699b136ea
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unordered-containers-0.2.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/unordered-containers-0.2.7.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/unordered-containers-0.2.7.1
hs-libraries: HSunordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unordered-containers-0.2.7.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.7.2
id: unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
key: unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
license: BSD3
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
author: Johan Tibell
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.PopCount Data.HashMap.Unsafe Data.HashMap.UnsafeShift
abi: 21f4a4119b52dcc8871e4c86082e4126
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unordered-containers-0.2.7.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/unordered-containers-0.2.7.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/unordered-containers-0.2.7.2
hs-libraries: HSunordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
